@@ -82,14 +82,92 @@ for t in range(int(len(Ctot)/2)):
 C = Ctot[0:int(len(Ctot)/2)].real
 # =============================================================================
 
-
-quasiparticles_kpoints, quasiparticles_info, raw_data_info = np.zeros((Nqs_path, 3)), np.zeros((Nqs_path, 3, tot_atoms_uc*3)), np.zeros((Nqs_path, 3, tot_atoms_uc*3))
+# =============================================================================
+# Spectra calcuation for path input by user
 print('\nDone. Performing calculation of renormalised FORCE CONSTANTS...\n')
-kpoints_scaled, kpoints = util.get_kgrid(N1,N2,N3, Hk)
-# you're not using irreducible kpoints anymore, couse it doesn't work for BaTiO3, unless you do adjustments
-# irr_kpoints, irr_kpoints_scaled, weights, permutations_types = util.get_irr_ks(kpoints, kpoints_scaled)
+quasiparticles_kpoints, quasiparticles_info, raw_data_info = np.zeros((Nqs_path, 3)), np.zeros((Nqs_path, 3, tot_atoms_uc*3)), np.zeros((Nqs_path, 3, tot_atoms_uc*3))
+for i in range(Nqs_path):
+    k = ks_path[i]
+    k_scal = ks_path_scaled[i]
+    # thisk_permutations = permutations_types[i]
+    # weight = weights[i]
+    print('\t kpoint scaled: ', i, k_scal)
+    # print('\t weight: ', weight)
+    
+# =============================================================================
+# harmonic things
+    D = util.get_D(k, K,N1,N2,N3,R0,masses_uc, tot_atoms_uc, SCell)
+    eigvals, eigvecs, omegas = util.get_eigvals_eigvec(D)
+    eigvecH = np.conjugate(eigvecs.T)
+# =============================================================================
+    
+# =============================================================================
+#  MD 
+    #Creating the collective variable based on the k point
+    Tkt = util.create_Tkt(Num_timesteps-1, tot_atoms_uc, N1N2N3, Vt, R0_repeat, k)    
+    tau, freq, Sq = util.get_power_spectrum2(Tkt, dt_ps, cev/(kbev*T), Nb)
+    area_q = np.trapz(Sq, freq)
+    print('\t DOS for this kpoint: ', area_q)
+    
+    #Projecting onto eigenvectors
+    Qkt = np.dot(eigvecH,Tkt.T).T
+    tau, freq_proj, Sq_proj = util.get_power_spectrum_proj2(Qkt, dt_ps, cev/(kbev*T), Nb)
+    area_q_proj = np.trapz(Sq_proj, freq, axis=0)
+    print('\t DOS for projected k-ni: ', area_q_proj)
+    # area_q_proj[area_q_proj < 1e-05] = 100 # this is in case of acoustic Gamma
+    # Sq_proj = Sq_proj/area_q_proj # this is to have the unoccupied DOS
+
+
+    Params = np.zeros((3,tot_atoms_uc*3))
+    raw_data_Params = np.zeros((3,tot_atoms_uc*3))
+    for n in range(tot_atoms_uc*3):
+        x_data, y_data = freq[0:int(tau/2)], Sq_proj[0:int(tau/2),n]
+        
+        popt, perr = util.fit_to_lorentzian(x_data, y_data, k, n)
+        Params[:,n] = popt
+        #now you go apply to Voigt equation for the sigmas
+        fmax, fl = util.voigt_eq(n, k_scal, x_data, y_data, sig=popt[-1]*0.42)
+        Params[-1,n] = fl
+        
+        x_avg, std = util.get_avg_std(x_data, y_data, k, n)
+        raw_data_Params[0,n], raw_data_Params[-1,n] = x_avg, std
+        print()
+        print('\t\tFitting to Lorentzian, mode '+str(n)+'...')
+        print('\t\tResonant frequency omega =',np.round(popt[0],2),' +-',np.round(perr[0],3))
+        print('\t\tLinewidth gamma =',np.round(popt[2],2),' +-',np.round(perr[2],3))
+        print()
+        print('\t\tTreating it as a prob density, mode '+str(n)+'...')
+        print('\t\tResonant frequency omega =',np.round(x_avg,2))
+        print('\t\tLinewidth gamma =',np.round(std,2))
+        print()
+        print()
+# =============================================================================
+        
+# =============================================================================
+#  MD writing to file    
+    quasiparticles_kpoints[i,:] = k_scal
+    quasiparticles_info[i,:,:] = Params
+    raw_data_info[i,:,:] = raw_data_Params
+    ZS[:,i+2] = Sq[0:meta]
+    Zqs[i,:,0] = Sq[0:meta]
+    Zqs[i,:,1:] = Sq_proj[0:meta,:]
+
+util.save_quasiparticles('Zqs', quasiparticles_kpoints, Zqs)
+util.save_quasiparticles('quasiparticles', quasiparticles_kpoints, quasiparticles_info)  
+util.save_quasiparticles('non_quasiparticles', quasiparticles_kpoints, raw_data_info)  
+util.save('C_t', np.vstack((tall[0:len(C)],C)).T)
+util.save('ZS', ZS)
+# =============================================================================
+    
+
+
+# =============================================================================
+# Renormalized force calculation
+print('\nDone. Performing calculation of renormalised FORCE CONSTANTS...\n')
+# Nqs_irr, irr_kpoints, irr_kpoints_scaled, weights, permutations_types = util.get_irr_ks(kpoints, kpoints_scaled) # you're not using irreducible kpoints anymore, couse it doesn't work for BaTiO3, unless you do adjustments
+Nqs, kpoints_scaled, kpoints = util.get_kgrid(N1,N2,N3, Hk)
 Ds = np.zeros((len(kpoints),tot_atoms_uc*3, tot_atoms_uc*3), dtype=complex)
-for i in range(len(kpoints)):
+for i in range(Nqs):
     k = kpoints[i]
     k_scal = kpoints_scaled[i]
     # thisk_permutations = permutations_types[i]
@@ -125,7 +203,6 @@ for i in range(len(kpoints)):
 
 
     Params = np.zeros((3,tot_atoms_uc*3))
-    raw_data_Params = np.zeros((3,tot_atoms_uc*3))
     for n in range(tot_atoms_uc*3):
         x_data, y_data = freq[0:int(tau/2)], Sq_proj[0:int(tau/2),n]
         
@@ -134,21 +211,6 @@ for i in range(len(kpoints)):
         #now you go apply to Voigt equation for the sigmas
         fmax, fl = util.voigt_eq(n, k_scal, x_data, y_data, sig=popt[-1]*0.42)
         Params[-1,n] = fl
-        
-        x_avg, std = util.get_avg_std(x_data, y_data, k, n)
-        raw_data_Params[0,n], raw_data_Params[-1,n] = x_avg, std
-        
-        if(np.any(np.all(np.isclose(k_scal , ks_path_scaled), axis=1))):
-            print()
-            print('\t\tFitting to Lorentzian, mode '+str(n)+'...')
-            print('\t\tResonant frequency omega =',np.round(popt[0],2),' +-',np.round(perr[0],3))
-            print('\t\tLinewidth gamma =',np.round(popt[2],2),' +-',np.round(perr[2],3))
-            print()
-            print('\t\tTreating it as a prob density, mode '+str(n)+'...')
-            print('\t\tResonant frequency omega =',np.round(x_avg,2))
-            print('\t\tLinewidth gamma =',np.round(std,2))
-            print()
-            print()
 # =============================================================================
 
 # =============================================================================
@@ -161,31 +223,9 @@ for i in range(len(kpoints)):
 # =============================================================================
 
 # =============================================================================
-#  writing to file if in path
-    check_is_symm_kpoint = util.check_is_symm(k_scal, ks_path_scaled)
-    if(len(check_is_symm_kpoint) > 0):
-        # print(check_is_symm_kpoint)
-        for l in range(len(check_is_symm_kpoint)):
-            kpoint = check_is_symm_kpoint[l]
-            index_q = np.argwhere(np.all(np.isclose(kpoint , ks_path_scaled), axis=1)).flatten()
-            quasiparticles_kpoints[index_q,:] = kpoint
-            quasiparticles_info[index_q,:,:] = Params
-            raw_data_info[index_q,:,:] = raw_data_Params
-            ZS[:,index_q+2] = Sq[0:meta].reshape(meta,1)
-            Zqs[index_q,:,0] = Sq[0:meta]
-            Zqs[index_q,:,1:] = Sq_proj[0:meta,:]
-# =============================================================================
-    print()
-
-    
-util.save_quasiparticles('Zqs', quasiparticles_kpoints, Zqs)
-util.save_quasiparticles('quasiparticles', quasiparticles_kpoints, quasiparticles_info)  
-util.save_quasiparticles('non_quasiparticles', quasiparticles_kpoints, raw_data_info)  
-util.save('C_t', np.vstack((tall[0:len(C)],C)).T)
-util.save('ZS', ZS)
-
-# SCell_fc, R0_fc, R_fc = util.get_R_FC(N1, N2, N3, 4,4,4,tot_atoms_uc, Suc, SCell) 
+# K_renorm writing to file
 K_renorm = util.get_K_renorm_old(tot_atoms_uc,N1,N2,N3, SCell, R0, kpoints, Ds)
-# K_renorm = util.get_K_renorm(tot_atoms_uc,N1,N2,N3, SCell, R0, irr_kpoints, permutations_types, Ds)
 print('Calculated renormalized FORCE CONSTANTS')
 util.save('K_renorm', K_renorm)
+# =============================================================================
+
