@@ -186,6 +186,7 @@ def save_proj(x,y,ytot,convolution, k,freq,n,namedir, params, max_Z):
 def plot_k2(kk, kk_many, frequencies_disp, frequencies_ft, f, data, data_projected, indexes, max_Z, branches):
     mpl.rcParams.update(pgf_with_latex)
     num_ks = len(data_projected[0,0,:])
+    num_ks_path = len(data[0,:])
     tot_branches = int(len(frequencies_disp[:,0]))
     plt.ion()
     dk = kk_many[1] - kk_many[0]
@@ -199,7 +200,7 @@ def plot_k2(kk, kk_many, frequencies_disp, frequencies_ft, f, data, data_project
         max_Z = np.max(data_projected)
     
     fig, ax = plt.subplots()
-    if(len(branches) == tot_branches): #plot whole spectrum
+    if(len(branches) == tot_branches and num_ks == num_ks_path): #plot whole spectrum
         print('Drawing the whole spectrum...')
         ax.pcolormesh(X,Y,data, vmax=max_Z, cmap='Blues')
         print('finished')
