@@ -754,6 +754,18 @@ def all_kpoints(N1,N2,N3, Hk):
     allkpoints = np.dot(Hk,allkpoints_scaled)
     return allkpoints_scaled.T, allkpoints.T
 
+def apply_nac(i, k, K, ks_path_many, BORN_file, SCell, N1, N2, N3, tot_atoms_uc, masses_uc):
+    N1N2N3 = N1*N2*N3
+    if(np.allclose(k, [0,0,0])):
+        kpoint_nac = ks_path_many[i+1]
+    else:
+        kpoint_nac = k
+    eps_inf, BORN, Vuc = get_nac_params(BORN_file, SCell, N1, N2, N3, tot_atoms_uc)
+    C_nac = get_nac_C(kpoint_nac, Vuc, BORN, eps_inf, masses_uc, N1N2N3)
+    K_corr = get_K_corr(K, C_nac)
+    return K_corr
+
+
 def get_K_renorm_old(tot_atoms_uc, N1, N2, N3, H, R0, kpoints, Ds):
     """
     old getK_renorm, without exploiting irreducible ks
